@@ -4,7 +4,10 @@
 #		start the portmapper before mounting (this is needed for
 #		Linux 2.1.x and up).
 #
-# Version:	@(#)mountnfs.sh  1.11  05-Oct-1998  miquels@cistron.nl
+#		Also mounts SBM filesystems now, so the name of
+#		this script is getting increasingly inaccurate.
+#
+# Version:	@(#)mountnfs.sh  1.20  11-Feb-2000  miquels@cistron.nl
 #
 
 . /etc/default/rcS
@@ -21,19 +24,38 @@ test -f /etc/fstab && (
 #
 portmap=no
 mount_nfs=no
+mount_smb=no
 while read device mountpt fstype options
 do
+	case "$device" in
+		""|\#*)
+			continue
+			;;
+	esac
 	if [ "$fstype" = nfs ]
 	then
-		mount_nfs=yes
 		case "$options" in
+			*noauto*)
+				;;
 			*nolock*)
+				mount_nfs=yes
 				;;
 			*)
+				mount_nfs=yes
 				portmap=yes
 				;;
 		esac
 	fi
+	if [ "$fstype" = smbfs ]
+	then
+		case "$options" in
+			*noauto*)
+				;;
+			*)
+				mount_smb=yes
+				;;
+		esac
+	fi
 done
 
 exec 0>&1
@@ -48,10 +70,11 @@ then
 	fi
 fi
 
-if [ "$mount_nfs" = yes ]
+if [ "$mount_nfs" = yes ] || [ "$mount_smb" = yes ]
 then
 	echo "Mounting remote filesystems..."
-	mount -a -t nfs
+	[ "$mount_nfs" = yes ] && mount -a -t nfs
+	[ "$mount_smb" = yes ] && mount -a -t smbfs
 fi
 
 ) < /etc/fstab
